@@ -1,6 +1,9 @@
 # MODULES
 from dataclasses import dataclass, field
 from typing import List
+from pathlib import Path
+
+from wafermap_clustering.models.clustering_performance import ClusteringPerformance
 
 # MODELS
 from ..models.clustered_defect import ClusteredDefect
@@ -16,7 +19,8 @@ class ClusteringResult:
     wafer_id: str
     clusters: int
     clustered_defects: List[ClusteredDefect] = field(default=lambda: [])
-    processing_timestamp: float = field(default=lambda: None)
+    performance: ClusteringPerformance = None
+    output_filename: Path = field(default_factory=lambda: None)
 
     @property
     def number_of_defects(self):
