@@ -54,6 +54,8 @@ class Clustering:
                 clustering = DBSCAN(
                     eps=self.config.clustering.dbscan.eps,
                     min_samples=self.config.clustering.dbscan.min_samples,
+                    algorithm="ball_tree",
+                    metric="haversine",
                 )
             case ClusteringMode.HDBSCAN.value:
                 clustering = HDBSCAN(
@@ -63,6 +65,8 @@ class Clustering:
             case _:
                 raise ValueError(f"{clustering_mode=} is not supported")
 
+        self.logger.info(f"Prepare to cluster {len(klarf_content.wafers)} wafers")
+
         results: List[ClusteringResult] = []
         for index, wafer in enumerate(klarf_content.wafers):
             tic = time.time()
@@ -71,10 +75,19 @@ class Clustering:
                 klarf_content=klarf_content, wafer_index=index
             )
 
+            lot = single_klarf.lot_id
+            wafer_id = single_klarf.wafer.id
+
+            self.logger.info(
+                f"Preparing to perform clustering for {lot=} and {wafer_id=} using {clustering_mode=}"
+            )
+
             if len(wafer.defects) == 0:
                 clusters = 0
                 clustered_defects = []
                 clustering_timestamp = 0
+
+                self.logger.info(f"{lot=} and {wafer_id=} do not have any defects")
             else:
                 defect_ids = np.array([defect.id for defect in wafer.defects])
                 defect_points = np.array(
@@ -84,6 +97,10 @@ class Clustering:
                     ]
                 )
 
+                self.logger.info(
+                    f"Starting clustering process for {lot=} and {wafer_id=} on {len(defect_points)} defects"
+                )
+
                 labels = clustering.fit_predict(defect_points)
 
                 clustering_values = np.column_stack((defect_ids, labels))
@@ -113,6 +130,10 @@ class Clustering:
                 ),
             )
 
+            self.logger.info(
+                f"Clustering complete. Found {clusters} clusters on {len(clustered_defects)} defects."
+            )
+
             output_timestamp = None
             if klarf_format == KlarfFormat.BABY.value and output_directory is not None:
                 output_filename = (
